var annotated =
[
    [ "classid_map", "structclassid__map.html", "structclassid__map" ],
    [ "dumb", "structdumb.html", "structdumb" ],
    [ "genl_cmd", "structgenl__cmd.html", "structgenl__cmd" ],
    [ "genl_info", "structgenl__info.html", "structgenl__info" ],
    [ "genl_ops", "structgenl__ops.html", "structgenl__ops" ],
    [ "inet6_data", "structinet6__data.html", "structinet6__data" ],
    [ "ip6_tnl_info", "structip6__tnl__info.html", "structip6__tnl__info" ],
    [ "ipgre_info", "structipgre__info.html", "structipgre__info" ],
    [ "ipip_info", "structipip__info.html", "structipip__info" ],
    [ "ipvti_info", "structipvti__info.html", "structipvti__info" ],
    [ "meta_data", "structmeta__data.html", "structmeta__data" ],
    [ "nbyte_data", "structnbyte__data.html", "structnbyte__data" ],
    [ "nfnl_ct_timestamp", "structnfnl__ct__timestamp.html", "structnfnl__ct__timestamp" ],
    [ "nl_cli_tc_module", "structnl__cli__tc__module.html", "structnl__cli__tc__module" ],
    [ "nl_derived_object", "structnl__derived__object.html", "structnl__derived__object" ],
    [ "nl_dump_params", "structnl__dump__params.html", "structnl__dump__params" ],
    [ "nl_hash_node", "structnl__hash__node.html", "structnl__hash__node" ],
    [ "nl_hash_table", "structnl__hash__table.html", "structnl__hash__table" ],
    [ "nl_list_head", "structnl__list__head.html", "structnl__list__head" ],
    [ "nla_policy", "structnla__policy.html", "structnla__policy" ],
    [ "rtnl_basic", "structrtnl__basic.html", "structrtnl__basic" ],
    [ "rtnl_ematch_ops", "structrtnl__ematch__ops.html", "structrtnl__ematch__ops" ],
    [ "rtnl_link", "structrtnl__link.html", null ],
    [ "rtnl_meta_value", "structrtnl__meta__value.html", "structrtnl__meta__value" ],
    [ "rtnl_pktloc", "structrtnl__pktloc.html", "structrtnl__pktloc" ],
    [ "rtnl_rtcacheinfo", "structrtnl__rtcacheinfo.html", "structrtnl__rtcacheinfo" ],
    [ "sit_info", "structsit__info.html", "structsit__info" ],
    [ "text_data", "structtext__data.html", "structtext__data" ],
    [ "vlan_map", "structvlan__map.html", "structvlan__map" ],
    [ "yy_buffer_state", "structyy__buffer__state.html", "structyy__buffer__state" ],
    [ "yy_trans_info", "structyy__trans__info.html", "structyy__trans__info" ],
    [ "yyalloc", "unionyyalloc.html", "unionyyalloc" ],
    [ "yyguts_t", "structyyguts__t.html", "structyyguts__t" ],
    [ "YYLTYPE", "structYYLTYPE.html", "structYYLTYPE" ],
    [ "YYSTYPE", "unionYYSTYPE.html", "unionYYSTYPE" ]
];